@@ -26,6 +26,7 @@ struct package_group
   gchar *name;
   GList *categories;
   GList *items;
+  gboolean hide;
 };
 
 /* main window */
@@ -46,4 +47,6 @@ char *get_icon_fn (GnomeDesktopFile *p, int iconsize);
 
 void run_package (GnomeDesktopFile *p);
 
+gchar *only_group;
+
 #endif
